#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# imports: project
from libmonty_logging import helper


def config(program_name: str, program_version: str) -> dict:
    log_file_path: str = helper.log_file_path(program_name, program_version)

    return {
        'version': 1,
        'formatters': {
            'form01': {
                'format': '[%(asctime)s] [%(levelname)-8s] %(message)s',
                'datefmt': '%H:%M:%S'
            },
            'form02': {
                'format': '[%(asctime)s] [%(levelname)-8s] %(message)s'
            }
        },
        'handlers': {
            'hand01': {
                'class': 'logging.StreamHandler',
                'level': 'INFO',
                'formatter': 'form01',
                'stream': 'ext://sys.stdout'
            },
            'hand02': {
                'class': 'logging.FileHandler',
                'level': 'INFO',
                'formatter': 'form02',
                'filename': log_file_path,
                'mode': 'w',
                'encoding': 'UTF-8'
            }
        },
        'loggers': {
            'root': {
                'level': 'NOTSET',
                'handlers': ['hand01', 'hand02']
            }
        }
    }



#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# imports: library
import logging


def program_header(program_name: str,
                   program_version: str = None,
                   underliner: str = '-'
                   ) -> None:

    if len(underliner) != 1:
        raise ValueError(f'Argument "underliner" must be 1 character long: "{underliner}"')

    header = f'{program_name}'
    
    if program_version is not None:
        header += f' {program_version}'

    logging.info(header)
    logging.info('-' * len(header))



#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# imports: library
from argparse import ArgumentParser

# imports: project
from libmonty_logging import version


def main() -> None:

    parser = ArgumentParser(prog=version.PROGRAM_NAME)

    parser.add_argument('--version',
                        help='Display version',
                        action='store_true',
                        dest='version')

    args = parser.parse_args()

    if args.version:
        print(f'{version.PROGRAM_NAME} {version.__version__}')
        return


if __name__ == '__main__':
    main()

# -------------------------------------------------------------------- #



#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# imports: library
import logging.config
import os.path
from typing import Callable

# imports: dependencies
from xdg_base_dirs import xdg_state_home


def _state_dir_path(program_name: str) -> str:
    state_dir_path = os.path.join(xdg_state_home(), program_name)

    if not os.path.isdir(state_dir_path):
        os.makedirs(state_dir_path, mode=0o740, exist_ok=True)

    return state_dir_path


def _log_file_name(program_name: str, program_version: str) -> str:
    return f'{program_name}-{program_version}.log'


def log_file_path(program_name: str, program_version: str) -> str:
    state_dir_path: str = _state_dir_path(program_name)
    log_file_name: str = _log_file_name(program_name, program_version)
    return os.path.join(state_dir_path, log_file_name)

def apply_config(program_name: str, program_version: str, configurator: Callable) -> None:
    config = configurator(program_name, program_version)
    logging.config.dictConfig(config)
